#
# spec file for package python-efl
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-efl
Version:        1.18.0
Release:        3.11
Summary:        Python bindings of evas
License:        GPL-3.0 and LGPL-3.0
Group:          Development/Libraries/Python
Url:            http://enlightenment.org
Source:         %{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  python-cython
BuildRequires:  pkgconfig(dbus-python)
BuildRequires:  pkgconfig(ecore)
BuildRequires:  pkgconfig(edje)
BuildRequires:  pkgconfig(elementary)
BuildRequires:  pkgconfig(emotion)
BuildRequires:  pkgconfig(eo)
BuildRequires:  pkgconfig(evas)
BuildRequires:  pkgconfig(python)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
# pre-unification mess
Obsoletes:      python-evas < %{version}
Provides:       python-evas = %{version}
Obsoletes:      python-ecore < %{version}
Provides:       python-ecore = %{version}
Obsoletes:      python-edje < %{version}
Provides:       python-edje = %{version}
Obsoletes:      python-emotion < %{version}
Provides:       python-emotion = %{version}
Obsoletes:      python-e_dbus < %{version}
Provides:       python-e_dbus = %{version}
Obsoletes:      python-elementary < %{version}
Provides:       python-elementary = %{version}

%description
Python bindings of evas library, part of EFL.

%package doc
Summary:        Documentation for python-efl
Group:          Documentation/HTML
BuildRequires:  python-sphinx

%description doc
HTML formated documentation for python-efl module.

%package examples
Summary:        Examples of python-efl usage
Group:          Documentation/Other

%description examples
Some examples of usage of python-efl.

%prep
%setup -q
# drop build date from doc to fix build-compare
sed -i "s/\(html_last_updated_fmt = \).*/\\1None/" ./doc/conf.py

%build
python setup.py build -g
python setup.py build_doc

%install
export DISABLE_CYTHON=1

# module itself
python setup.py install --prefix="%{_prefix}" --root=%{buildroot}

# documentation
install -m 0755 -d "%{buildroot}/%{_docdir}/%{name}"
cp -R build/sphinx/html "%{buildroot}/%{_docdir}/%{name}"
rm "%{buildroot}/%{_docdir}/%{name}"/html/.buildinfo
%if 0%{?suse_version}
%fdupes -s "%{buildroot}/%{_docdir}/%{name}"
%endif

# examples
install -m 0755 -d "%{buildroot}/%{_datadir}/%{name}"
cp -R examples/  "%{buildroot}/%{_datadir}/%{name}/"
mkdir -p %{buildroot}/%{_docdir}/%{name}
cp -pr COPYING %{buildroot}/%{_docdir}/%{name}/
cp -pr COPYING.LESSER %{buildroot}/%{_docdir}/%{name}/
cp -pr AUTHORS %{buildroot}/%{_docdir}/%{name}/

%files
%defattr(-,root,root)
%{_libdir}/python*/*/*
%{_docdir}/%{name}/
%exclude %{_docdir}/%{name}/html/

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/html/

%files examples
%defattr(-,root,root)
%{_datadir}/%{name}

%changelog
* Tue Aug 23 2016 sflees@suse.de
- Update to 1.18.0 to match efl
* Sun Aug 21 2016 sflees@suse.de
- Drop  python-efl-reproducible.patch fixed upstream
* Fri Jul  1 2016 toddrme2178@gmail.com
- Fix Group tags.
* Wed Mar  9 2016 bwiedemann@suse.com
- Add python-efl-reproducible.patch to fix build-compare
* Sun Feb  7 2016 simon@simotek.net
- 1.17.0 Release of Python bindings for efl
* Sat Jan  9 2016 simon@simotek.net
- Drop python3 stuff for factory submition
* Fri Dec 18 2015 simon@simotek.net
- A python3 spec file has been added to this package, in preperation
  for a dual spec build of python2 and python3 it will have no impact
  on this package
* Fri Dec 18 2015 simon@simotek.net
- 1.16.0 - All the new features of efl and elementary 1.16 has been
  ported and the usual has been done in fixing bugs and optimizing
  speed.
* Sat Nov 14 2015 simon@simotek.net
- 1.16.0 pre release will add full changes with release
* Fri Aug 21 2015 simon@simotek.net
- Add COPYING.* AUTHORS to package
* Sat Aug 15 2015 simon@simotek.net
- Bindings update to efl 1.15.x
  Fixes:
    elm.Entry: Fixed name of the callback_rejected_del function
    Fixed build on OSX
    Fixed build when ecore-x is not available
    Fixed module init from embedded interpreter
  Changes:
    Elm: Unify modules into a monolithic module
  Additions:
    elm.Configuration.transition_duration_factor
    elm.Window.autohide
    elm.ELM_POLICY_QUIT_LAST_WINDOW_HIDDEN
    elm.Entry.callback_context_open_add/del
    elm.ELM_FOCUS_MOVE_POLICY_KEY_ONLY
    elm.Object.focus_move_policy
    elm.Scrollable.wheel_disabled
    evas.Textblock.obstacle_add
    evas.Textblock.obstacle_del
    evas.Textblock.obstacles_update
    evas.EVAS_CALLBACK_CANVA_VIEWPORT_RESIZE
* Thu May  7 2015 simon@simotek.net
- Bindings updated to efl 1.14.X
* Mon Feb 16 2015 simon@simotek.net
- Bindings updated to match efl 1.13.x
* Fri Jan  9 2015 simon@simotek.net
- Bindings updated to match efl 1.12.x
* Tue Sep 16 2014 simon@simotek.net
- bump to 1.11.0
  * * Re enabled cython building **
  No new features upstream just following efl changes
* Mon Aug 18 2014 simon@simotek.net
- Disabled Cython with env var for this release as the upstream tar was broken.
  It was missing .pxd files this has been fixed for the next release.
* Sun Jun  1 2014 sleep_walker@suse.cz
- bump to 1.10.0 (but missing any short changelog)
- correct all provides and obsoletes
* Wed Apr  9 2014 simon@simotek.net
- version 1.9.0
  Release Notes:
  No major changes have been made since the last 1.8 release. All the new
  features of efl and elementary 1.9 has been ported and the usual has been
  done in fixing bugs and optimizing speed. (see **changes.html** in the
  tarball for the full list of changes)
* Tue Dec 17 2013 sleep_walker@suse.cz
- change to use pkgconfig dependencies
- beutify spec a bit
* Mon Dec  9 2013 sleep_walker@suse.cz
- let there by python-efl!
